@@ -198,7 +198,7 @@ def update_tuple(tablename, user_id, tuple_id, tuple_values, project_id=None):
             result = query.update(tuple_values)
         except Exception as e:
             raise freezer_api_exc.StorageEngineError(
-                message='Mysql operation failed {0}'.format(e))
+                message='sql operation failed {0}'.format(e))
 
     if not result:
         raise freezer_api_exc.DocumentNotFound(
@@ -383,12 +383,12 @@ def get_client(user_id, project_id=None, client_id=None, offset=0,
 
     for client in result:
         clientmap = {}
-        clientmap[u'project_id'] = client.project_id
-        clientmap[u'user_id'] = client.user_id
-        clientmap[u'client'] = {u'uuid': client.uuid,
-                                u'hostname': client.hostname,
-                                u'client_id': client.client_id,
-                                u'description': client.description}
+        clientmap['project_id'] = client.project_id
+        clientmap['user_id'] = client.user_id
+        clientmap['client'] = {'uuid': client.uuid,
+                               'hostname': client.hostname,
+                               'client_id': client.client_id,
+                               'description': client.description}
         clients.append(clientmap)
 
     # If search opt is wrong, filter will not work,
