@@ -16,8 +16,8 @@
 """Tests for manipulating Action via the DB API"""
 
 import copy
-import mock
-from mock import patch
+from unittest import mock
+from unittest.mock import patch
 
 from freezer_api.common import exceptions as freezer_api_exc
 from freezer_api.tests.unit import common
@@ -69,8 +69,8 @@ class DbActionTestCase(base.DbTestCase):
         self.assertEqual(freezer_action.get('container'),
                          self.freezer_action_0.get('container'))
 
-        self.assertEqual(freezer_action.get('src_file'),
-                         self.freezer_action_0.get('src_file'))
+        self.assertEqual(freezer_action.get('path_to_backup'),
+                         self.freezer_action_0.get('path_to_backup'))
 
         self.assertEqual(freezer_action.get('mode'),
                          self.freezer_action_0.get('mode'))
